@@ -19,8 +19,8 @@
 #' @param min_occurrence Threshold to define which pixels count towards the GSW
 #' occurrence area `[0, 100]`.
 #' @keywords indicator
-#' @returns A function that returns a tibble with a column for the aggregated
-#'   GSW occurrence indicator.
+#' @returns A function that returns an indicator tibble with occurrence as
+#'   variable and the corresponding area (in ha) as value.
 #' @include register.R
 #' @export
 #' @examples
@@ -102,7 +102,7 @@ calc_gsw_occurrence <- function(engine = "extract", min_occurrence = NULL) {
       tidyr::pivot_longer(cols = dplyr::everything(), names_to = "variable") %>%
       dplyr::mutate(
         variable = "gsw_occurrence",
-        datetime = as.Date("2021-01-01"),
+        datetime = as.POSIXct("2021-01-01T00:00:00Z"),
         unit = "ha"
       ) %>%
       dplyr::select(datetime, variable, unit, value)
